@@ -37,7 +37,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(new_user_amazon run_aws_cmd get_aws_security_id
                  launch_server $configure_aws1 $pem_file $credpath
-                 $configure_aws3 $aws);
+                 $aws_configure $aws);
 our $pem_file='';
 our $credpath='.';
 our $aws={};
@@ -332,7 +332,7 @@ sub launch_server {
    $configure_server->($server_type,$cnt,$selection,$server_host_block);
 }
 
-our $configure_aws3=sub {
+our $aws_configure=sub {
 
    my $username=&Net::FullAuto::FA_Core::username();
    if (-1<$#_) {
@@ -382,25 +382,25 @@ our $configure_aws3=sub {
                $line.=$_;
                if ($line=~/Access Key ID \[None\]:\s*$/) {
                   for (1..length $line) {
-                     $pty->ungetc(\000);
+                     $pty->ungetc(ord);
                   }
                   $line='';
                   $pty->print("$main::aws->{access_id}\n");
                } elsif ($line=~/Secret Access Key \[None\]:\s*$/) {
                   for (1..length $line) {
-                     $pty->ungetc(\000);
+                     $pty->ungetc(ord);
                   }
                   $line='';
                   $pty->print("$main::aws->{secret_key}\n");
                } elsif ($line=~/Default region name \[None\]:\s*$/) {
                   for (1..length $line) {
-                     $pty->ungetc(\000);
+                     $pty->ungetc(ord);
                   }
                   $line='';
                   $pty->print("$region\n");
                } elsif ($line=~/Default output format \[None\]:\s*$/) {
                   for (1..length $line) {
-                     $pty->ungetc(\000);
+                     $pty->ungetc(ord);
                   }
                   $pty->print("\n");
                }
@@ -451,7 +451,7 @@ END
       Name => 'configure_aws2',
       Input  => 1,
       Banner => $banner,
-      Result => $configure_aws3,
+      Result => $aws_configure,
 
    );
    return \%configure_aws2;
@@ -1105,7 +1105,7 @@ sub new_user_amazon {
       my $id='';my $aki='';my $sak='';
       chomp $creds[1];
       ($id,$aki,$sak)=split ',',$creds[1];
-      $configure_aws3->($aki,$sak);
+      $aws_configure->($aki,$sak);
       unlink "$credentials_csv_path/credentials.csv";
    }
    if ($cleanup) {
